@@ -19,11 +19,14 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "config.h"
+
 #include <glib.h>
 #include <glib-unix.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <gio/gio.h>
+#include <locale.h>
 #include <packagekit-glib2/packagekit.h>
 #include <packagekit-glib2/packagekit-private.h>
 #include <packagekit-glib2/pk-offline-private.h>
@@ -31,9 +34,6 @@
 #include <unistd.h>
 #include <systemd/sd-journal.h>
 
-/**
- * pk_offline_update_set_plymouth_msg:
- **/
 static void
 pk_offline_update_set_plymouth_msg (const gchar *msg)
 {
@@ -57,9 +57,6 @@ pk_offline_update_set_plymouth_msg (const gchar *msg)
 	}
 }
 
-/**
- * pk_offline_update_set_plymouth_mode:
- **/
 static void
 pk_offline_update_set_plymouth_mode (const gchar *mode)
 {
@@ -83,9 +80,6 @@ pk_offline_update_set_plymouth_mode (const gchar *mode)
 	}
 }
 
-/**
- * pk_offline_update_set_plymouth_percentage:
- **/
 static void
 pk_offline_update_set_plymouth_percentage (guint percentage)
 {
@@ -108,9 +102,6 @@ pk_offline_update_set_plymouth_percentage (guint percentage)
 	}
 }
 
-/**
- * pk_offline_update_progress_cb:
- **/
 static void
 pk_offline_update_progress_cb (PkProgress *progress,
 			       PkProgressType type,
@@ -188,9 +179,6 @@ pk_offline_update_progress_cb (PkProgress *progress,
 	}
 }
 
-/**
- * pk_offline_update_reboot:
- **/
 static int
 pk_offline_update_reboot (void)
 {
@@ -214,8 +202,10 @@ pk_offline_update_reboot (void)
 					   "org.freedesktop.systemd1",
 					   "/org/freedesktop/systemd1",
 					   "org.freedesktop.systemd1.Manager",
-					   "Reboot",
-					   NULL,
+					   "StartUnit",
+					   g_variant_new("(ss)",
+							 "reboot.target",
+							 "replace-irreversibly"),
 					   NULL,
 					   G_DBUS_CALL_FLAGS_NONE,
 					   -1,
@@ -231,9 +221,6 @@ pk_offline_update_reboot (void)
 	return EXIT_SUCCESS;
 }
 
-/**
- * pk_offline_update_power_off:
- **/
 static int
 pk_offline_update_power_off (void)
 {
@@ -257,8 +244,10 @@ pk_offline_update_power_off (void)
 					   "org.freedesktop.systemd1",
 					   "/org/freedesktop/systemd1",
 					   "org.freedesktop.systemd1.Manager",
-					   "PowerOff",
-					   NULL,
+					   "StartUnit",
+					   g_variant_new("(ss)",
+							 "poweroff.target",
+							 "replace-irreversibly"),
 					   NULL,
 					   G_DBUS_CALL_FLAGS_NONE,
 					   -1,
@@ -274,9 +263,6 @@ pk_offline_update_power_off (void)
 	return EXIT_SUCCESS;
 }
 
-/**
- * pk_offline_update_write_error:
- **/
 static void
 pk_offline_update_write_error (const GError *error)
 {
@@ -297,9 +283,6 @@ pk_offline_update_write_error (const GError *error)
 		sd_journal_print (LOG_WARNING, "%s", error_local->message);
 }
 
-/**
- * pk_offline_update_write_results:
- **/
 static void
 pk_offline_update_write_results (PkResults *results)
 {
@@ -342,9 +325,6 @@ pk_offline_update_write_dummy_results (void)
 	sync ();
 }
 
-/**
- * pk_offline_update_loop_quit_cb:
- **/
 static gboolean
 pk_offline_update_loop_quit_cb (gpointer user_data)
 {
@@ -353,9 +333,6 @@ pk_offline_update_loop_quit_cb (gpointer user_data)
 	return FALSE;
 }
 
-/**
- * pk_offline_update_sigint_cb:
- **/
 static gboolean
 pk_offline_update_sigint_cb (gpointer user_data)
 {
@@ -446,9 +423,6 @@ pk_offline_update_do_upgrade (PkTask *task, PkProgressBar *progressbar, GError *
 	return TRUE;
 }
 
-/**
- * main:
- **/
 int
 main (int argc, char *argv[])
 {
@@ -461,6 +435,11 @@ main (int argc, char *argv[])
 	g_autoptr(PkProgressBar) progressbar = NULL;
 	g_autoptr(PkTask) task = NULL;
 
+	setlocale (LC_ALL, "");
+	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
 	/* ensure root user */
 	if (getuid () != 0 || geteuid () != 0) {
 		retval = EXIT_FAILURE;
