@@ -44,6 +44,10 @@ typedef struct _PkDetailsPrivate	PkDetailsPrivate;
 typedef struct _PkDetails		PkDetails;
 typedef struct _PkDetailsClass		PkDetailsClass;
 
+#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PkDetails, g_object_unref)
+#endif
+
 struct _PkDetails
 {
 	 PkSource		 parent;
@@ -70,6 +74,7 @@ PkGroupEnum	 pk_details_get_group			(PkDetails	*details);
 const gchar	*pk_details_get_description		(PkDetails	*details);
 const gchar	*pk_details_get_url			(PkDetails	*details);
 guint64		 pk_details_get_size			(PkDetails	*details);
+const gchar     *pk_details_get_summary                 (PkDetails      *details);
 
 G_END_DECLS
 
