@@ -80,11 +80,12 @@ struct _PkResultsClass
 
 GType		 pk_results_get_type		  	(void);
 PkResults	*pk_results_new				(void);
-void		 pk_results_test			(gpointer		 user_data);
 
 /* set */
 gboolean	 pk_results_set_exit_code		(PkResults		*results,
 							 PkExitEnum		 exit_enum);
+gboolean	 pk_results_set_role	 		(PkResults		*results,
+							 PkRoleEnum		 role);
 gboolean	 pk_results_set_error_code 		(PkResults		*results,
 							 PkError		*item);
 
